# Minimal Chocolatey-compatible NuGet server in a Django app

See above.

## Installation

```shell
pip install django-minchoc
```

```python
ALLOW_PACKAGE_DELETION = False
WANT_NUGET_HOME = True
```
